%define anolis_release 1

Name:           pmix
Version:        4.2.8
Release:        %{anolis_release}%{?dist}
Summary:        Process Management Interface Exascale (PMIx)
License:        BSD-3-Clause
URL:            https://www.openpmix.org
Source0:        https://github.com/openpmix/openpmix/releases/download/v%{version}/%{name}-%{version}.tar.bz2
# file missing from release
Source1:        construct_event_strings.py

# comes from https://github.com/openpmix/openpmix/commit/142625e507d831cd641623925843d58576e06803
Patch0001: 	https://github.com/openpmix/openpmix/pull/3245.patch
Patch0002: 	Replace-inet_addr-with-inet_pton.patch

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  flex
BuildRequires:  gcc
BuildRequires:  hwloc-devel
BuildRequires:  libevent-devel
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  munge-devel
BuildRequires:  perl-interpreter
BuildRequires:  zlib-devel
Provides:	OpenPMIx = %{version}-%{release}
Provides:	openpmix = %{version}-%{release}

%description
The Process Management Interface (PMI) has been used for quite some time as
a means of exchanging wireup information needed for interprocess
communication. Two versions (PMI-1 and PMI-2) have been released as part of
the MPICH effort. While PMI-2 demonstrates better scaling properties than its
PMI-1 predecessor, attaining rapid launch and wireup of the roughly 1M
processes executing across 100k nodes expected for exascale operations remains
challenging.

PMI Exascale (PMIx) represents an attempt to resolve these questions by
providing an extended version of the PMI standard specifically designed to
support clusters up to and including exascale sizes. The overall objective of
the project is not to branch the existing pseudo-standard definitions - in
fact, PMIx fully supports both of the existing PMI-1 and PMI-2 APIs - but
rather to (a) augment and extend those APIs to eliminate some current
restrictions that impact scalability, and (b) provide a reference
implementation of the PMI-server that demonstrates the desired level of
scalability.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-tools = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        tools
Summary:        Tools for %{name}
Requires:       %{name} = %{version}-%{release}
Conflicts:	%{name} < 4.2.6

%description    tools
The %{name}-tools package contains for use with PMIx-based RMs and language-
based starters (e.g., mpirun).

* pinfo - show MCA params, build info, etc.
* pps - get list of active nspaces, retrieve status of jobs/nodes/procs
* pevent - inject an event into the system

%package        doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n pmix-%{version} -p1
cp %{S:1} contrib/

# touch lexer sources to recompile them
find src -name \*.l -print -exec touch --no-create {} \;

%build
export CFLAGS="%{build_cflags} -Wno-unused-function -Wno-attributes"
%ifarch x86_64
export CPPFLAGS="$CPPFLAGS -fcf-protection"
%endif
%ifarch aarch64
export CPPFLAGS="$CPPFLAGS -mbranch-protection=standard"
%endif
%configure \
    --prefix=%{_prefix} \
    --sysconfdir=%{_sysconfdir}/%{name} \
    --disable-static \
    --disable-silent-rules \
    --with-tests-examples \
    --enable-wrapper-rpath=no \
    --enable-wrapper-runpath=no \
    --enable-ipv6 \
    --enable-shared \
    --with-munge

%make_build

%check
%make_build check

%install
%make_install

# set up pmix self-test infra for install
install -d -m 0755 %{buildroot}%{_datadir}/%{name}/test
for f in pmix_client pmix_regex
do
  mv test/.libs/$f %{buildroot}%{_datadir}/%{name}/$f
done
mv test/.libs/pmix_test %{buildroot}%{_datadir}/%{name}/test/pmix_test

%generate_compatibility_deps

%files
%license LICENSE
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/test
%dir %{_libdir}/%{name}
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/*.conf
%{_datadir}/%{name}/*.txt
%{_datadir}/%{name}/pmix_*
%{_datadir}/%{name}/test/pmix_test
%{_libdir}/libpmix.so.2*
%{_libdir}/%{name}/*.so
%{_mandir}/man3/*.3*
%{_mandir}/man5/*.5*
%doc html
%dir %{abidir}
%{abidir}/libpmix.dump
%{abidir}/pmix_mca_pcompress_zlib.dump
%{abidir}/pmix_mca_prm_default.dump
%{abidir}/pmix_mca_prm_slurm.dump

%files devel
%{_datadir}/%{name}/*.supp
%{_includedir}/pmix
%{_includedir}/pmix*.h
%{_libdir}/libpmix.so
%{_libdir}/pkgconfig/*.pc

%files tools
%{_bindir}/pattrs
%{_bindir}/pctrl
%{_bindir}/pevent
%{_bindir}/plookup
%{_bindir}/pmix_info
%{_bindir}/pmixcc
%{_bindir}/pps
%{_bindir}/pquery
%{_mandir}/man1/pmix_info.1*
%{abidir}/pattrs-option.list
%{abidir}/pevent-option.list
%{abidir}/plookup-option.list
%{abidir}/pps-option.list
%{abidir}/pquery-option.list
%{abidir}/pmix_info-option.list

%files doc
%doc README.md

%changelog
* Mon Mar 17 2025 happy_orange <songnannan@linux.alibaba.com> - 4.2.8-1
- update to 4.2.8
- Fix CPPFLAGS use for x86 and arm
- Fix rpminspect failures for aarch64
- Add pmix_test and pmix_regex in test
- Enable IPv6 support and tests examples support, and disable wrapper rpath
- Use SPDX license identifier
  [Patches cherry-picked from c10s. Original changelog:
  - Fix CPPFLAGS use for aarch64.(4.2.8-8)]

* Wed Sep 20 2023 Funda Wang <fundawang@yeah.net> - 4.2.6-1
- New version 4.2.6

* Tue Mar 28 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 4.2.3-1
- Init from upstream
